import { AfterViewInit, ChangeDetectorRef, EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Subscription } from 'rxjs';
import { Element } from '@angular/compiler';
import * as i0 from "@angular/core";
/**
 * [AppBar Component](https://brightlayer-ui-components.github.io/angular/?path=/info/components-app-bar--readme)
 *
 * The `<blui-app-bar>` component is a wrapper around the `<mat-toolbar>` that can be resized as the page is scrolled.
 * It supports three variants: `snap`, `collapsed`, and `expanded`.
 * */
export declare class AppBarComponent implements OnInit, AfterViewInit, OnChanges, OnDestroy {
    private readonly _ref;
    /** Height (pixels) of the AppBar when collapsed */
    collapsedHeight: number;
    /** Color variant which is passed to the `<mat-toolbar>`
     *
     * @default primary
     * */
    color: 'primary' | 'accent' | 'warn' | undefined;
    /** Height (pixels) of the AppBar when expanded
     *
     * @default 200
     * */
    expandedHeight: number;
    /** Scrollable element which dynamic app bar responds to.  This element is searched in the DOM `ngAfterViewInit`.*/
    scrollContainerElement: Element;
    /** Class name, index number of scrollable element. This element is searched in the DOM `ngAfterViewInit`. */
    scrollContainerClassName: {
        name: string;
        index: number;
    };
    /** Id of the scrollable element. This element is searched in the DOM `ngAfterViewInit`.  */
    scrollContainerId: string;
    /** Distance in pixels to scroll before collapsing toolbar. */
    scrollThreshold: number;
    /** Behavior of the App Bar
     *
     *  `collapsed` - Height set to `collapsedHeight` and does not respond to scroll distance
     *
     *  `expanded` -  Height set to `expandedHeight` and does not respond to scroll distance
     *
     *  `snap` - Variant that responds to scroll distance and switches between the `collapsed` and `expanded` variant.
     *
     *  @default collapsed
     *
     * */
    variant: 'collapsed' | 'expanded' | 'snap';
    /** Event emitter for when the appbar opens or closes.  Emits a boolean that indicates whether the AppBar is expanded. */
    collapsedChange: EventEmitter<boolean>;
    scrollEl: any;
    isCollapsed: boolean;
    isWindow: boolean;
    useDefaultCollapsedHeight: boolean;
    isAnimating: boolean;
    viewInit: boolean;
    scrollListener: Subscription;
    resizeListener: Subscription;
    contentSize: number;
    constructor(_ref: ChangeDetectorRef);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    private _stopListeningForScrollEvents;
    calcCurrentToolbarHeight(): string;
    private _listenForScrollEvents;
    private _resizeOnModeChange;
    private _handleLockedModes;
    private _setCollapsed;
    private _resizeEl;
    private _setScrollEl;
    private _calcDefaultCollapsedHeight;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppBarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AppBarComponent, "blui-app-bar", never, { "collapsedHeight": "collapsedHeight"; "color": "color"; "expandedHeight": "expandedHeight"; "scrollContainerElement": "scrollContainerElement"; "scrollContainerClassName": "scrollContainerClassName"; "scrollContainerId": "scrollContainerId"; "scrollThreshold": "scrollThreshold"; "variant": "variant"; }, { "collapsedChange": "collapsedChange"; }, never, ["[blui-icon]", "*", "[blui-actions]"], false, never>;
}
